@@ -22,7 +22,7 @@ from aliyunsdkcore.request import RpcRequest
 class CreatePipelineRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'devops-rdc', '2020-03-03', 'CreatePipeline')
+		RpcRequest.__init__(self, 'devops-rdc', '2020-03-03', 'CreatePipeline','1.9.6')
 		self.set_method('POST')
 
 	def get_Pipeline(self):
