@@ -22,7 +22,7 @@ from aliyunsdkcore.request import RpcRequest
 class ListDevopsProjectTasksRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'devops-rdc', '2020-03-03', 'ListDevopsProjectTasks')
+		RpcRequest.__init__(self, 'devops-rdc', '2020-03-03', 'ListDevopsProjectTasks','1.9.6')
 		self.set_method('POST')
 
 	def get_ProjectIds(self):
